==> qmmp_0.2.3.orig.tar.gz: qmmp-0.2.3/src/plugins/Input/modplug/translations/modplug_plugin_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="cs">
<context>
    <name>DecoderModPlugFactory</name>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="40"/>
        <source>ModPlug Plugin</source>
        <translation>Modul ModPlug</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="44"/>
        <source>ModPlug Files</source>
        <translation>Soubory ModPlug</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="108"/>
        <source>About ModPlug Audio Plugin</source>
        <translation>O modulu ModPlug</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="109"/>
        <source>Qmmp ModPlug Audio Plugin</source>
        <translation>Vstupní modul Qmmp ModPlug</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="110"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autor: Ilja Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="111"/>
        <source>Based on the Modplug Plugin for Xmms</source>
        <translation>Založeno na modulu Modplug pro XMMS</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="112"/>
        <source>Modplug Plugin developers:</source>
        <translation>Vývojáři modulu Modplug:</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="113"/>
        <source>Olivier Lapicque &lt;olivierl@jps.net&gt;</source>
        <translation>Olivier Lapicque &lt;olivierl@jps.net&gt;</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="114"/>
        <source>Kenton Varda &lt;temporal@gauge3d.org&gt;</source>
        <translation>Kenton Varda &lt;temporal@gauge3d.org&gt;</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="115"/>
        <source>Konstanty Bialkowski &lt;konstanty@ieee.org&gt;</source>
        <translation>Konstanty Bialkowski &lt;konstanty@ieee.org&gt;</translation>
    </message>
</context>
<context>
    <name>DetailsDialog</name>
    <message>
        <location filename="../detailsdialog.ui" line="46"/>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="45"/>
        <source>Title:</source>
        <translation>Název:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="133"/>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="47"/>
        <source>Length:</source>
        <translation>Délka:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="52"/>
        <source>Channels:</source>
        <translation>Počet kanálů:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="44"/>
        <source>File name:</source>
        <translation>Název souboru:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="46"/>
        <source>Type:</source>
        <translation>Typ:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="48"/>
        <source>Speed:</source>
        <translation>Rychlost:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="49"/>
        <source>Tempo:</source>
        <translation>Tempo:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="50"/>
        <source>Samples:</source>
        <translation>Vzorky:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="51"/>
        <source>Instruments:</source>
        <translation>Nástroje:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="52"/>
        <source>Patterns:</source>
        <translation>Patterny:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="13"/>
        <source>MOD Info</source>
        <translation>Informace o modulu</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="30"/>
        <source>General</source>
        <translation>Obecné</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="57"/>
        <source>Samples</source>
        <translation>Vzorky</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="106"/>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Arial&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Arial&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="77"/>
        <source>Instruments</source>
        <translation>Nástroje</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="97"/>
        <source>Message</source>
        <translation>Zpráva</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="800"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="814"/>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="13"/>
        <source>ModPlug Plugin Settings</source>
        <translation>Nastavení modulu ModPlug</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="23"/>
        <source>Quality</source>
        <translation>Kvalita</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="35"/>
        <source>Resolution</source>
        <translation>Rozlišení</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="41"/>
        <source>16 bit</source>
        <translation>16 bitů</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="48"/>
        <source>8 bit</source>
        <translation>8 bitů</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="64"/>
        <source>Channels</source>
        <translation>Kanály</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="70"/>
        <source>Stereo</source>
        <translation>Stereo</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="77"/>
        <source>Mono (downmix)</source>
        <translation>Mono (mix)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="93"/>
        <source>Resampling</source>
        <translation>Převzorkování</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="99"/>
        <source>Nearest (fastest)</source>
        <translation>Nejbližší (nejrychlejší)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="106"/>
        <source>Linear (fast)</source>
        <translation>Lineární (rychlé)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="113"/>
        <source>Spline (good quality)</source>
        <translation>Kubické (spline) (kvalitní)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="120"/>
        <source>8-tap Fir (extremely high quality)</source>
        <translation>FIR 8. řádu (extrémní kvalita)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="136"/>
        <source>Sampling Rate</source>
        <translation>Vzorkovací frekvence</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="142"/>
        <source>48000 Hz</source>
        <translation>48000 Hz</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="149"/>
        <source>44100 Hz</source>
        <translation>44100 Hz</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="156"/>
        <source>22050 Hz</source>
        <translation>22050 Hz</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="163"/>
        <source>11025 Hz</source>
        <translation>11025 Hz</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="174"/>
        <source>Effects</source>
        <translation>Efekty</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="180"/>
        <source>Reverb</source>
        <translation>Dozvuk</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="457"/>
        <source>Depth (%)</source>
        <translation>Hloubka (%)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="608"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="509"/>
        <source>Delay (ms)</source>
        <translation>Zpoždění (ms)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="282"/>
        <source>40</source>
        <translation>40</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="314"/>
        <source>Bass Boost</source>
        <translation>Zdůraznění basů</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="326"/>
        <source>Amount (%)</source>
        <translation>Síla (%)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="384"/>
        <source>Range (Hz)</source>
        <translation>Rozsah (Hz)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="416"/>
        <source>10</source>
        <translation>10</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="448"/>
        <source>Surround</source>
        <translation>Surround</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="541"/>
        <source>5</source>
        <translation>5</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="567"/>
        <source>Preamp</source>
        <translation>Předzesílení</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="576"/>
        <source>Volume</source>
        <translation>Hlasitost</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="646"/>
        <source>Note: Setting the preamp
too high may cause clipping!</source>
        <translation>Pozor: Nastavení příliš vysokého
předzesílení může způsobit přebuzení!</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="661"/>
        <source>Misc</source>
        <translation>Různé</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="667"/>
        <source>General</source>
        <translation>Obecné</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="673"/>
        <source>Use filename as song title</source>
        <translation>Použít název souboru jako název skladby</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="680"/>
        <source>Noise reduction</source>
        <translation>Odstranění šumu</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="690"/>
        <source>Fast playlist info</source>
        <translation>Rychlé informace o seznamu skladeb</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="700"/>
        <source>Play Amiga MOD</source>
        <translation>Přehrát Amiga modul</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="710"/>
        <source>Looping</source>
        <translation>Smyčky</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="716"/>
        <source>Don&apos;t loop</source>
        <translation>Neopakovat</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="723"/>
        <source>Loop</source>
        <translation>Opakovat</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="740"/>
        <source>time(s)</source>
        <translation>krát</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="760"/>
        <source>Loop forever</source>
        <translation>Donekonečna</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="807"/>
        <source>Apply</source>
        <translation>Aplikovat</translation>
    </message>
</context>
</TS>

==> qmmp_0.3.1.orig.tar.gz: qmmp-0.3.1/src/plugins/Input/modplug/translations/modplug_plugin_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="cs">
<context>
    <name>DecoderModPlugFactory</name>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="60"/>
        <source>ModPlug Plugin</source>
        <translation>Modul ModPlug</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="64"/>
        <source>ModPlug Files</source>
        <translation>Soubory ModPlug</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="133"/>
        <source>About ModPlug Audio Plugin</source>
        <translation>O modulu ModPlug</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="134"/>
        <source>Qmmp ModPlug Audio Plugin</source>
        <translation>Vstupní modul Qmmp ModPlug</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="135"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autor: Ilja Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="136"/>
        <source>Based on the Modplug Plugin for Xmms</source>
        <translation>Založeno na modulu Modplug pro XMMS</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="137"/>
        <source>Modplug Plugin developers:</source>
        <translation>Vývojáři modulu Modplug:</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="138"/>
        <source>Olivier Lapicque &lt;olivierl@jps.net&gt;</source>
        <translation>Olivier Lapicque &lt;olivierl@jps.net&gt;</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="139"/>
        <source>Kenton Varda &lt;temporal@gauge3d.org&gt;</source>
        <translation>Kenton Varda &lt;temporal@gauge3d.org&gt;</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="140"/>
        <source>Konstanty Bialkowski &lt;konstanty@ieee.org&gt;</source>
        <translation>Konstanty Bialkowski &lt;konstanty@ieee.org&gt;</translation>
    </message>
</context>
<context>
    <name>DetailsDialog</name>
    <message>
        <location filename="../detailsdialog.ui" line="36"/>
        <location filename="../detailsdialog.ui" line="46"/>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="44"/>
        <source>Title:</source>
        <translation>Název:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="133"/>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="46"/>
        <source>Length:</source>
        <translation>Délka:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="52"/>
        <source>Channels:</source>
        <translation>Počet kanálů:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="43"/>
        <source>File name:</source>
        <translation>Název souboru:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="45"/>
        <source>Type:</source>
        <translation>Typ:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="47"/>
        <source>Speed:</source>
        <translation>Rychlost:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="48"/>
        <source>Tempo:</source>
        <translation>Tempo:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="49"/>
        <source>Samples:</source>
        <translation>Vzorky:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="50"/>
        <source>Instruments:</source>
        <translation>Nástroje:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="51"/>
        <source>Patterns:</source>
        <translation>Patterny:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="13"/>
        <source>MOD Info</source>
        <translation>Informace o modulu</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="30"/>
        <source>General</source>
        <translation>Obecné</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="57"/>
        <source>Samples</source>
        <translation>Vzorky</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="66"/>
        <location filename="../detailsdialog.ui" line="86"/>
        <location filename="../detailsdialog.ui" line="106"/>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Arial&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Arial&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="77"/>
        <source>Instruments</source>
        <translation>Nástroje</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="97"/>
        <source>Message</source>
        <translation>Zpráva</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="13"/>
        <source>ModPlug Plugin Settings</source>
        <translation>Nastavení modulu ModPlug</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="23"/>
        <source>Quality</source>
        <translation>Kvalita</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="35"/>
        <source>Resolution</source>
        <translation>Rozlišení</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="41"/>
        <source>16 bit</source>
        <translation>16 bitů</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="48"/>
        <source>8 bit</source>
        <translation>8 bitů</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="64"/>
        <source>Channels</source>
        <translation>Kanály</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="70"/>
        <source>Stereo</source>
        <translation>Stereo</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="77"/>
        <source>Mono (downmix)</source>
        <translation>Mono (mix)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="93"/>
        <source>Resampling</source>
        <translation>Převzorkování</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="99"/>
        <source>Nearest (fastest)</source>
        <translation>Nejbližší (nejrychlejší)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="106"/>
        <source>Linear (fast)</source>
        <translation>Lineární (rychlé)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="113"/>
        <source>Spline (good quality)</source>
        <translation>Kubické (spline) (kvalitní)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="120"/>
        <source>8-tap Fir (extremely high quality)</source>
        <translation>FIR 8. řádu (extrémní kvalita)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="136"/>
        <source>Sampling Rate</source>
        <translation>Vzorkovací frekvence</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="142"/>
        <source>48000 Hz</source>
        <translation>48000 Hz</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="149"/>
        <source>44100 Hz</source>
        <translation>44100 Hz</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="156"/>
        <source>22050 Hz</source>
        <translation>22050 Hz</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="163"/>
        <source>11025 Hz</source>
        <translation>11025 Hz</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="174"/>
        <source>Effects</source>
        <translation>Efekty</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="180"/>
        <source>Reverb</source>
        <translation>Dozvuk</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="192"/>
        <location filename="../settingsdialog.ui" line="457"/>
        <source>Depth (%)</source>
        <translation>Hloubka (%)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="224"/>
        <location filename="../settingsdialog.ui" line="358"/>
        <location filename="../settingsdialog.ui" line="489"/>
        <location filename="../settingsdialog.ui" line="608"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="250"/>
        <location filename="../settingsdialog.ui" line="509"/>
        <source>Delay (ms)</source>
        <translation>Zpoždění (ms)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="282"/>
        <source>40</source>
        <translation>40</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="314"/>
        <source>Bass Boost</source>
        <translation>Zdůraznění basů</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="326"/>
        <source>Amount (%)</source>
        <translation>Síla (%)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="384"/>
        <source>Range (Hz)</source>
        <translation>Rozsah (Hz)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="416"/>
        <source>10</source>
        <translation>10</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="448"/>
        <source>Surround</source>
        <translation>Surround</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="541"/>
        <source>5</source>
        <translation>5</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="567"/>
        <source>Preamp</source>
        <translation>Předzesílení</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="576"/>
        <source>Volume</source>
        <translation>Hlasitost</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="646"/>
        <source>Note: Setting the preamp
too high may cause clipping!</source>
        <translation>Pozor: Nastavení příliš vysokého
předzesílení může způsobit přebuzení!</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="661"/>
        <source>Misc</source>
        <translation>Různé</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="667"/>
        <source>General</source>
        <translation>Obecné</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="673"/>
        <source>Use filename as song title</source>
        <translation>Použít název souboru jako název skladby</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="680"/>
        <source>Noise reduction</source>
        <translation>Odstranění šumu</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="690"/>
        <source>Fast playlist info</source>
        <translation>Rychlé informace o seznamu skladeb</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="700"/>
        <source>Play Amiga MOD</source>
        <translation>Přehrát Amiga modul</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="710"/>
        <source>Looping</source>
        <translation>Smyčky</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="716"/>
        <source>Don&apos;t loop</source>
        <translation>Neopakovat</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="723"/>
        <source>Loop</source>
        <translation>Opakovat</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="740"/>
        <source>time(s)</source>
        <translation>krát</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="760"/>
        <source>Loop forever</source>
        <translation>Donekonečna</translation>
    </message>
</context>
</TS>
